dm: core: Rename the priv/plat members

These are supposed to be private to driver model, not accessed by any code
outside. Add a trailing underscore to indicate this.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/dm/uclass.h b/include/dm/uclass.h
index 20d4b9e..f06339e 100644
--- a/include/dm/uclass.h
+++ b/include/dm/uclass.h
@@ -24,7 +24,7 @@
  * There may be drivers for on-chip SoC GPIO banks, I2C GPIO expanders and
  * PMIC IO lines, all made available in a unified way through the uclass.
  *
- * @priv: Private data for this uclass
+ * @priv_: Private data for this uclass (do not access outside driver model)
  * @uc_drv: The driver for the uclass itself, not to be confused with a
  * 'struct driver'
  * @dev_head: List of devices in this uclass (devices are attached to their
@@ -32,7 +32,7 @@
  * @sibling_node: Next uclass in the linked list of uclasses
  */
 struct uclass {
-	void *priv;
+	void *priv_;
 	struct uclass_driver *uc_drv;
 	struct list_head dev_head;
 	struct list_head sibling_node;
diff --git a/include/dm/device.h b/include/dm/device.h
index 30fc98d..daebd6e 100644
--- a/include/dm/device.h
+++ b/include/dm/device.h
@@ -116,17 +116,22 @@
  *
  * @driver: The driver used by this device
  * @name: Name of device, typically the FDT node name
  * @plat: Configuration data for this device
  * @parent_plat: The parent bus's configuration data for this device
  * @uclass_plat: The uclass's configuration data for this device
  * @node: Reference to device tree node for this device
  * @driver_data: Driver data word for the entry that matched this device with
  *		its driver
  * @parent: Parent of this device, or NULL for the top level device
- * @priv: Private data for this device
+ * @priv_: Private data for this device (do not access outside driver model)
  * @uclass: Pointer to uclass for this device
- * @uclass_priv: The uclass's private data for this device
- * @parent_priv: The parent's private data for this device
+ * @uclass_priv_: The uclass's private data for this device (do not access
+ *	outside driver model)
+ * @parent_priv_: The parent's private data for this device (do not access
+ *	outside driver model)
  * @uclass_node: Used by uclass to link its devices
  * @child_head: List of children of this device
  * @sibling_node: Next device in list of all devices
@@ -144,16 +149,16 @@
 struct udevice {
 	const struct driver *driver;
 	const char *name;
-	void *plat;
-	void *parent_plat;
-	void *uclass_plat;
+	void *plat_;
+	void *parent_plat_;
+	void *uclass_plat_;
 	ofnode node;
 	ulong driver_data;
 	struct udevice *parent;
-	void *priv;
+	void *priv_;
 	struct uclass *uclass;
-	void *uclass_priv;
-	void *parent_priv;
+	void *uclass_priv_;
+	void *parent_priv_;
 	struct list_head uclass_node;
 	struct list_head child_head;
 	struct list_head sibling_node;
@@ -116,17 +116,22 @@
  * @driver: The driver used by this device
  * @name: Name of device, typically the FDT node name
- * @plat: Configuration data for this device
- * @parent_plat: The parent bus's configuration data for this device
- * @uclass_plat: The uclass's configuration data for this device
+ * @plat_: Configuration data for this device (do not access outside driver
+ *	model)
+ * @parent_plat_: The parent bus's configuration data for this device (do not
+ *	access outside driver model)
+ * @uclass_plat_: The uclass's configuration data for this device (do not access
+ *	outside driver model)
  * @node: Reference to device tree node for this device
  * @driver_data: Driver data word for the entry that matched this device with